@@ -10,9 +10,10 @@
 #' @examples
 #' # Select some text in a source file
 #' # Then call the function as an RStudio addin
-#' \dontrun{addin_chatgpt_in_source()}
+#' \dontrun{
+#' addin_chatgpt_in_source()
+#' }
 addin_chatgpt_in_source <- function() {
-  cli_inform(c("i" = "Sending query to ChatGPT..."))
   gpt_chat_in_source(
     style = getOption("gptstudio.code_style"),
     skill = getOption("gptstudio.skill")
