@@ -1,7 +1,7 @@
 sample_key <- "4f9bb533-c0ac-4fef-9f7a-9eabe1afcc24"
 
 test_that("OpenAI create completion fails with bad key", {
-  expect_snapshot(openai_create_completion(
+  expect_error(openai_create_completion(
     model = "text-davinci-003",
     prompt = "a test prompt",
     openai_api_key = sample_key
@@ -9,7 +9,7 @@ test_that("OpenAI create completion fails with bad key", {
 })
 
 test_that("OpenAI create edit fails with bad key", {
-  expect_snapshot(openai_create_edit(
+  expect_error(openai_create_edit(
     model = "text-davinci-edit-001",
     input = "I is a human.",
     temperature = 1,
@@ -17,25 +17,27 @@ test_that("OpenAI create edit fails with bad key", {
     openai_api_key = sample_key
   ))
 
-  expect_snapshot(openai_create_edit(
+  expect_error(openai_create_edit(
     model = "text-davinci-edit-001",
     input = "I is a human.",
     temperature = 1,
     instruction = "fix the grammar",
-    top_p = 1,
     openai_api_key = sample_key
   ))
 })
 
 test_that("OpenAI create chat completion fails with bad key", {
-  expect_snapshot(
-    openai_create_chat_completion(prompt = "What is your name?",
-                                  openai_api_key = sample_key)
+  expect_error(
+    openai_create_chat_completion(
+      prompt = "What is your name?",
+      openai_api_key = sample_key
+    )
   )
 })
 
 test_that("OpenAI create completion works", {
   skip_on_ci()
+  skip_on_cran()
   expect_type(
     openai_create_completion(
       model = "text-davinci-003",
@@ -48,6 +50,7 @@ test_that("OpenAI create completion works", {
 
 test_that("OpenAI create edit works", {
   skip_on_ci()
+  skip_on_cran()
   expect_type(
     openai_create_edit(
       model = "text-davinci-edit-001",
